import '../internal/inner_headers.dart';

///
///
///
/// 离线推送设置参数类。
///
class ChatSilentModeParam {
  final ChatSilentModeParamType _paramType;

  ///
  ///
  ///
  /// 离线推送通知类型。
  ///
  final ChatPushRemindType? remindType;

  ///
  ///
  ///
  /// 离线推送免打扰的开始时间。
  ///
  final ChatSilentModeTime? startTime;

  ///
  ///
  ///
  /// 离线推送免打扰结束时间。
  ///
  final ChatSilentModeTime? endTime;

  ///
  ///
  ///
  /// 离线push免打扰时长。
  ///
  final int? silentDuration;

  ///
  ///
  ///
  /// 设置离线推送通知类型。
  ///
  /// Param [remindType] 离线推送通知类型。
  ///
  ChatSilentModeParam.remindType(
    this.remindType,
  )   : this.silentDuration = null,
        this.startTime = null,
        this.endTime = null,
        this._paramType = ChatSilentModeParamType.REMIND_TYPE;

  ///
  ///
  ///
  /// 设置离线推免打扰时长。
  /// Param [silentDuration] 离线推送免打扰时长，单位为分钟。
  ///
  ChatSilentModeParam.silentDuration(this.silentDuration)
      : this.startTime = null,
        this.endTime = null,
        this.remindType = null,
        this._paramType = ChatSilentModeParamType.SILENT_MODE_DURATION;

  ///
  ///
  ///
  /// 设置离线推送免打扰的开始时间，需要同时创建开始时间和结束时间。
  ///
  /// Param [startTime] 免扰乱开始时间。
  ///
  /// Param [endTime] 免扰乱结束时间。
  ///
  ChatSilentModeParam.silentModeInterval({
    required this.startTime,
    required this.endTime,
  })  : this.silentDuration = null,
        this.remindType = null,
        this._paramType = ChatSilentModeParamType.SILENT_MODE_INTERVAL;

  Map toJson() {
    Map data = Map();
    data.putIfNotNull("paramType", chatSilentModeParamTypeToInt(_paramType));
    data.putIfNotNull("remindType", chatPushRemindTypeToInt(remindType));
    data.putIfNotNull("startTime", startTime?.toJson());
    data.putIfNotNull("endTime", endTime?.toJson());
    data.putIfNotNull("duration", silentDuration);
    return data;
  }
}

///
///
///
/// 用于离线推送免打扰时间类。
///
class ChatSilentModeTime {
  ///
  ///
  ///
  /// 小时数。
  ///
  final int hour;

  ///
  ///
  ///
  /// 分钟
  ///
  final int minute;

  ///
  ///
  ///
  /// 用于离线推送免打扰时间。
  ///
  /// Param [hour] 设置小时数，为24小时制。
  ///
  /// Param [minute] 设置分钟数。
  ///
  ChatSilentModeTime({
    this.minute = 0,
    this.hour = 0,
  });

  Map toJson() {
    Map data = Map();
    data["minute"] = minute;
    data["hour"] = hour;
    return data;
  }

  factory ChatSilentModeTime.fromJson(Map map) {
    return ChatSilentModeTime(
      hour: map["hour"],
      minute: map["minute"],
    );
  }
}

///
///
///
/// 离线推送免打扰结果。
///
class ChatSilentModeResult {
  ///
  ///
  ///
  /// 获取离线推送免打扰到期时间戳。
  ///
  final int? expireTimestamp;

  ///
  ///
  ///
  /// 会话类型
  ///
  final EMConversationType conversationType;

  ///
  ///
  ///
  /// 会话ID
  ///
  final String conversationId;

  ///
  ///
  ///
  /// 离线推送通知类型。
  ///
  final ChatPushRemindType? remindType;

  ///
  ///
  ///
  /// 离线推送免打扰的开始时间。
  ///
  final ChatSilentModeTime? startTime;

  ///
  ///
  ///
  /// 离线推送免打扰结束时间。
  ///
  final ChatSilentModeTime? endTime;

  ///
  ///
  ///
  /// 离线推送免打扰结果类。
  ///
  ChatSilentModeResult(
    this.expireTimestamp,
    this.conversationType,
    this.conversationId,
    this.remindType,
    this.startTime,
    this.endTime,
  );

  factory ChatSilentModeResult.fromJson(Map map) {
    int expireTimestamp = map["expireTs"];
    ChatSilentModeTime startTime =
        ChatSilentModeTime.fromJson(map["startTime"]);
    ChatSilentModeTime endTime = ChatSilentModeTime.fromJson(map["endTime"]);
    ChatPushRemindType remindType =
        chatPushRemindTypeFromInt(map["remindType"]);
    String conversationId = map["conversationId"];
    EMConversationType conversationType =
        conversationTypeFromInt(map["conversationType"]);
    return ChatSilentModeResult(
      expireTimestamp,
      conversationType,
      conversationId,
      remindType,
      startTime,
      endTime,
    );
  }
}
