///
///
///
/// 群组类型枚举。
///
enum EMGroupStyle {
  ///
  ///
  ///
  /// 私有群组，创建完成后，只允许群主邀请用户加入。
  ///
  PrivateOnlyOwnerInvite,

  ///
  ///
  ///
  /// 私有群组，创建完成后，只允许群主和群成员邀请用户加入。
  ///
  PrivateMemberCanInvite,

  ///
  ///
  ///
  /// 公开群组，创建完成后，只允许群主邀请用户加入；非群成员用户需发送入群申请，群主同意后才能入群。
  ///
  PublicJoinNeedApproval,

  ///
  ///
  ///
  /// 公开群组，创建完成后，允许非群组成员加入，无需群主同意。
  ///
  PublicOpenJoin,
}

///
///
///
/// 会话类型枚举。
///
enum EMConversationType {
  ///
  ///
  ///
  /// 单聊。
  ///
  Chat,

  ///
  ///
  ///
  /// 群聊。
  ///
  GroupChat,

  ///
  ///
  ///
  /// 聊天室。
  ///
  ChatRoom,
}

///
///
///
/// 会话类型枚举。
///
enum ChatType {
  ///
  ///
  ///
  ///  单聊。
  ///
  Chat,

  ///
  ///
  ///
  /// 群聊。
  ///
  GroupChat,

  ///
  ///
  ///
  /// 聊天室。
  ///
  ChatRoom,
}

///
///
///
/// 消息的方向类型枚举类。
///
/// 区分是发送消息还是接收到的消息。
///
enum MessageDirection {
  ///
  ///
  ///
  /// 该消息是当前用户发送出去的。
  ///
  SEND,

  ///
  ///
  ///
  /// 该消息是当前用户接收到的。
  ///
  RECEIVE,
}

///
///
///
/// 消息的发送/接收状态枚举类。
///
enum MessageStatus {
  ///
  ///
  ///
  /// 消息已创建待发送。
  ///
  CREATE,

  ///
  ///
  ///
  /// 正在发送/接收。
  ///
  PROGRESS,

  ///
  ///
  ///
  /// 发送/接收成功。
  ///
  SUCCESS,

  ///
  ///
  ///
  /// 发送/接收失败。
  ///
  FAIL,
}

///
///
///
/// 消息附件的下载状态。
///
enum DownloadStatus {
  ///
  ///
  ///
  /// 等待下载。
  ///
  PENDING,

  ///
  ///
  ///
  /// 正在下载。
  ///
  DOWNLOADING,

  ///
  ///
  ///
  /// 下载成功。
  ///
  SUCCESS,

  ///
  ///
  ///
  /// 下载失败。
  ///
  FAILED,
}

///
///
///
/// 消息类型枚举。
///
enum MessageType {
  ///
  ///
  ///
  /// 文本消息。
  ///
  TXT,

  ///
  ///
  ///
  /// 图片消息。
  ///
  IMAGE,

  ///
  ///
  ///
  /// 视频消息。
  ///
  VIDEO,

  ///
  ///
  ///
  /// 位置消息。
  ///
  LOCATION,

  ///
  ///
  ///
  /// 语音消息。
  ///
  VOICE,

  ///
  ///
  ///
  /// 文件消息。
  ///
  FILE,

  ///
  ///
  ///
  /// 命令消息。
  ///
  CMD,

  ///
  ///
  ///
  /// 自定义消息。
  ///
  CUSTOM,

  ///
  ///
  ///
  /// 合并消息。
  ///
  COMBINE,
}

///
///
///
/// 群组角色类型枚举。
///
enum EMGroupPermissionType {
  ///
  ///
  ///
  /// 未知类型。
  ///
  None,

  ///
  ///
  ///
  /// 群组成员。
  ///
  Member,

  ///
  ///
  ///
  /// 群管理员。
  ///
  Admin,

  ///
  ///
  ///
  /// 群主。
  ///
  Owner,
}

///
///
///
/// 聊天室角色类型枚举。
///
enum EMChatRoomPermissionType {
  ///
  ///
  ///
  /// 未知类型。
  ///
  None,

  ///
  ///
  ///
  /// 普通成员。
  ///
  Member,

  ///
  ///
  ///
  /// 聊天室管理员。
  ///
  Admin,

  ///
  ///
  ///
  /// 聊天室所有者。
  ///
  Owner,
}

///
///
///
/// 消息检索方向类型枚举。
///
enum EMSearchDirection {
  ///
  ///
  ///
  /// 按消息中的时间戳的倒序搜索。
  ///
  Up,

  ///
  ///
  ///
  /// 按消息中的时间戳的顺序搜索。
  ///
  Down,
}

///
///
///
/// 多设备登录事件类型。
///
/// 本枚举类以用户 A 同时登录设备 A1 和 设备 A2 为例，描述多设备登录各事件的触发时机。
///

enum EMMultiDevicesEvent {
  ///
  ///
  ///
  /// 当前用户在其他设备上删除好友。
  ///
  CONTACT_REMOVE,

  ///
  ///
  ///
  /// 当前用户在其他设备上接受好友请求。
  ///
  CONTACT_ACCEPT,

  ///
  ///
  ///
  /// 当前用户在其他设备上拒绝好友请求。
  ///
  CONTACT_DECLINE,

  ///
  ///
  ///
  /// 当前用户在其他设备上将好友加入黑名单。
  ///
  CONTACT_BAN,

  ///
  ///
  ///
  /// 当前用户在其他设备上将好友移出黑名单。
  ///
  CONTACT_ALLOW,

  ///
  ///
  ///
  /// 当前用户在其他设备上创建群组。
  ///
  GROUP_CREATE,

  ///
  ///
  ///
  /// 当前用户在其他设备上解散群组。
  ///
  GROUP_DESTROY,

  ///
  ///
  ///
  /// 当前用户在其他设备上加入群组。
  ///
  GROUP_JOIN,

  ///
  ///
  ///
  /// 当前用户在其他设备离开群组。
  ///
  GROUP_LEAVE,

  ///
  ///
  ///
  /// 当前用户在其他设备上申请加入群组。
  ///
  GROUP_APPLY,

  ///
  ///
  ///
  /// 当前用户在其他设备接受入群申请。
  ///
  GROUP_APPLY_ACCEPT,

  ///
  ///
  ///
  /// 当前用户在其他设备上拒绝入群申请。
  ///
  GROUP_APPLY_DECLINE,

  ///
  ///
  ///
  /// 当前用户在其他设备上邀请用户入群。
  ///
  GROUP_INVITE,

  ///
  ///
  ///
  /// 当前用户在其他设备上接受了入群邀请。
  ///
  GROUP_INVITE_ACCEPT,

  ///
  ///
  ///
  /// 当前用户在其他设备上拒绝了入群邀请。
  ///
  GROUP_INVITE_DECLINE,

  ///
  ///
  ///
  /// 当前用户在其他设备上将成员踢出群。
  ///
  GROUP_KICK,

  ///
  ///
  ///
  /// 当前用户在其他设备上将成员加入群组黑名单。
  ///
  GROUP_BAN,

  ///
  ///
  ///
  /// 当前用户在其他设备上将成员移除群组黑名单。
  ///
  GROUP_ALLOW,

  ///
  ///
  ///
  /// 当前用户在其他设备上屏蔽群组。
  ///
  GROUP_BLOCK,

  ///
  ///
  ///
  /// 当前用户在其他设备上取消群组屏蔽。
  ///
  GROUP_UNBLOCK,

  ///
  ///
  ///
  /// 当前用户在其他设备上转移群组所有权。
  ///
  GROUP_ASSIGN_OWNER,

  ///
  ///
  ///
  /// 当前用户在其他设备上添加管理员。
  ///
  GROUP_ADD_ADMIN,

  ///
  ///
  ///
  /// 当前用户在其他设备上移除管理员。
  ///
  GROUP_REMOVE_ADMIN,

  ///
  ///
  ///
  /// 当前用户在其他设备上禁言成员。
  ///
  GROUP_ADD_MUTE,

  ///
  ///
  ///
  /// 当前用户在其他设备上解除禁言。
  ///
  GROUP_REMOVE_MUTE,

  ///
  ///
  ///
  /// 当前用户在其他设备将其他用户加入到群组白名单。
  ///
  GROUP_ADD_USER_ALLOW_LIST,

  ///
  ///
  ///
  /// 当前用户在其他设备将其他用户移除群组白名单。
  ///
  GROUP_REMOVE_USER_ALLOW_LIST,

  ///
  ///
  ///
  /// 当前用户在其他设备将全部群组成员禁言。
  ///
  GROUP_ALL_BAN,

  ///
  ///
  ///
  /// 当前用户在其他设备将群组成员解除禁言。
  ///
  GROUP_REMOVE_ALL_BAN,

  ///
  ///
  ///
  /// 用户的群组功能被关闭事件。
  ///
  GROUP_DISABLED,

  ///
  ///
  ///
  /// 当前用户的群组功能开启事件。
  ///
  GROUP_ABLE,

  ///
  GROUP_MEMBER_ATTRIBUTES_CHANGED,

  ///
  ///
  ///
  /// 当前用户在其他设备创建子区。
  ///
  CHAT_THREAD_CREATE,

  ///
  ///
  ///
  /// 当前用户在其他设备销毁子区。
  ///
  CHAT_THREAD_DESTROY,

  ///
  ///
  ///
  /// 当前用户在其他设备加入子区。
  ///
  CHAT_THREAD_JOIN,

  ///
  ///
  ///
  /// 当前用户在其他设备离开子区。
  ///
  CHAT_THREAD_LEAVE,

  ///
  ///
  ///
  /// 当前用户在其他设备更新子区信息。
  ///
  CHAT_THREAD_UPDATE,

  ///
  ///
  ///
  /// 当前用户在其他设备上将成员踢出子区。
  ///
  CHAT_THREAD_KICK,

  ///
  ///
  ///
  /// 当前用户在其他设备上置顶会话。
  ///
  CONVERSATION_PINNED,

  ///
  ///
  ///
  /// 当前用户在其他设备上取消会话置顶。
  ///
  CONVERSATION_UNPINNED,

  ///
  ///
  ///
  /// 当前用户在其他设备上删除了服务端的会话。
  ///
  CONVERSATION_DELETE,
}

///
///
///
/// 子区事件类型枚举。
///
enum EMChatThreadOperation {
  ///
  ///
  ///
  /// 未知类型。
  ///
  UnKnown,

  ///
  ///
  ///
  /// 子区创建。
  ///
  Create,

  ///
  ///
  ///
  /// 子区更新。
  ///
  Update,

  ///
  ///
  ///
  /// 子区删除。
  ///
  Delete,

  ///
  ///
  ///
  /// 更新子区最新一条消息。
  ///
  Update_Msg,
}

///
///
///
/// 推送通知展示方式。
///
enum DisplayStyle {
  ///
  ///
  ///
  /// 显示通用标题，如 “您有一条新消息”。
  ///
  Simple,

  ///
  ///
  ///
  /// 显示离线消息的内容。
  ///
  Summary,
}

///
///
///
/// 离线推送参数类型枚举类。
///
enum ChatSilentModeParamType {
  ///
  ///
  ///
  /// 离线推送通知类型。
  ///
  REMIND_TYPE,

  ///
  ///
  ///
  /// 离线推送免打扰时长。
  ///
  SILENT_MODE_DURATION,

  ///
  ///
  ///
  /// 离线推送免打扰时间段。
  ///
  SILENT_MODE_INTERVAL,
}

///
///
///
/// 离线推送通知类型枚举类。
///
enum ChatPushRemindType {
  ///
  ///
  ///
  /// 接收所有离线消息的推送通知。
  ///
  ALL,

  ///
  ///
  ///
  /// 仅接收提及某些用户的消息的推送通知。
  ///
  MENTION_ONLY,

  ///
  ///
  ///
  /// 不接收离线消息的推送通知。
  ///
  NONE,
}

///
///
///
/// 聊天室消息优先级。
///
enum ChatRoomMessagePriority {
  ///
  ///
  ///
  /// 高
  ///
  High,

  ///
  ///
  ///
  /// 中
  ///
  Normal,

  ///
  ///
  ///
  /// 低
  ///
  Low,
}

///
///
///
/// Reaction 操作类型。
///
enum ReactionOperate {
  ///
  ///
  ///
  /// 删除
  ///
  Remove,

  ///
  ///
  ///
  /// 添加
  ///
  Add,
}

enum LeaveReason {
  Kicked,
  Offline,
}
