import '../internal/inner_headers.dart';

///
///
///
/// 聊天室信息类，包含内存中的聊天室信息。
///
/// **Note**
/// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
///
class EMChatRoom {
  EMChatRoom._private({
    required this.roomId,
    this.name,
    this.description,
    this.owner,
    this.announcement,
    this.memberCount,
    this.maxUsers,
    this.adminList,
    this.memberList,
    this.blockList,
    this.muteList,
    this.isAllMemberMuted,
    this.permissionType = EMChatRoomPermissionType.None,
  });

  String toString() => toJson().toString();

  /// @nodoc
  factory EMChatRoom.fromJson(Map<String, dynamic> map) {
    return EMChatRoom._private(
        roomId: map["roomId"],
        name: map["name"],
        description: map["desc"],
        owner: map["owner"],
        memberCount: map["memberCount"],
        maxUsers: map["maxUsers"],
        adminList: map.getList("adminList"),
        memberList: map.getList("memberList"),
        blockList: map.getList("blockList"),
        muteList: map.getList("muteList"),
        announcement: map["announcement"],
        permissionType: chatRoomPermissionTypeFromInt(map["permissionType"]),
        isAllMemberMuted: map.boolValue("isAllMemberMuted"));
  }

  /// @nodoc
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['roomId'] = roomId;
    data.putIfNotNull("name", name);
    data.putIfNotNull("desc", description);
    data.putIfNotNull("owner", owner);
    data.putIfNotNull("memberCount", memberCount);
    data.putIfNotNull("maxUsers", maxUsers);
    data.putIfNotNull("adminList", adminList);
    data.putIfNotNull("memberList", memberList);
    data.putIfNotNull("blockList", blockList);
    data.putIfNotNull("muteList", muteList);
    data.putIfNotNull("announcement", announcement);
    data.putIfNotNull("isAllMemberMuted", isAllMemberMuted);
    data['permissionType'] = chatRoomPermissionTypeToInt(permissionType);

    return data;
  }

  ///
  ///
  ///
  /// 从内存中获取聊天室 ID。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final String roomId;

  ///
  ///
  ///
  /// 从内存中获取聊天室名称。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final String? name;

  ///
  ///
  ///
  /// 从内存中获取聊天室描述。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final String? description;

  ///
  ///
  ///
  /// 从内存中获取聊天室所有者 ID。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final String? owner;

  ///
  ///
  ///
  /// 从内存中获取聊天室公告。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final String? announcement;

  ///
  ///
  ///
  /// 从内存中获取聊天室在线用户数量。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final int? memberCount;

  ///
  ///
  ///
  /// 从内存中获取聊天室最大人数限制，在创建聊天室时设置。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：{[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final int? maxUsers;

  ///
  ///
  ///
  /// 从内存中获取聊天室管理员列表。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final List<String>? adminList;

  ///
  ///
  ///
  /// 从内存中获取聊天室成员列表。
  ///
  /// **Note**
  /// 如需最新数据，需从服务器获取：[EMChatRoomManager.fetchChatRoomMembers]。
  ///
  final List<String>? memberList;

  ///
  ///
  ///
  /// 从内存中获取聊天室黑名单列表。
  ///
  /// **Note**
  /// 如果需要获取最新值，请调用：[EMChatRoomManager.fetchChatRoomBlockList]。
  ///
  final List<String>? blockList;

  ///
  ///
  ///
  /// 从内存中获取禁言列表。
  ///
  /// **Note**
  /// 如果需要获取最新值，请调用 [EMChatRoomManager.fetchChatRoomMuteList]。
  ///
  final List<String>? muteList;

  ///
  ///
  ///
  /// 从内存中查看是否在全员禁言状态。
  /// - `true`：开启全员禁言。
  /// - `false`：关闭全员禁言。
  ///
  /// **Note**
  /// 如果需要获取最新值，请调用 [EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final bool? isAllMemberMuted;

  ///
  ///
  ///
  /// 从内存中获取当前用户在聊天室角色，详见 [EMChatRoomPermissionType]。
  ///
  /// **Note**
  /// 如果需要获取最新值，请调用 [EMChatRoomManager.fetchChatRoomInfoFromServer]。
  ///
  final EMChatRoomPermissionType permissionType;
}
