///
///
///
/// 用户属性类。
///
class EMUserInfo {
  ///
  ///
  ///
  /// 创建用户属性。
  ///
  EMUserInfo._private(
    this.userId, {
    this.nickName,
    this.avatarUrl,
    this.mail,
    this.phone,
    this.gender = 0,
    this.sign,
    this.birth,
    this.ext,
  });

  /// @nodoc
  factory EMUserInfo.fromJson(Map map) {
    EMUserInfo info = EMUserInfo._private(
      map["userId"],
      nickName: map["nickName"],
      avatarUrl: map["avatarUrl"],
      mail: map["mail"],
      phone: map["phone"],
      gender: map["gender"] ?? 0,
      sign: map["sign"],
      birth: map["birth"],
      ext: map["ext"],
    );
    return info;
  }

  /// @nodoc
  Map toJson() {
    Map data = Map();
    data['userId'] = userId;
    if (nickName != null) {
      data['nickName'] = nickName;
    }
    if (avatarUrl != null) {
      data['avatarUrl'] = avatarUrl;
    }
    if (mail != null) {
      data['mail'] = mail;
    }
    if (phone != null) {
      data['phone'] = phone;
    }
    data['gender'] = gender;
    if (sign != null) {
      data['sign'] = sign;
    }
    if (birth != null) {
      data['birth'] = birth;
    }
    if (ext != null) {
      data['ext'] = ext;
    }

    return data;
  }

  ///
  ///
  ///
  /// 用户 ID。
  ///
  final String userId;

  ///
  ///
  ///
  /// 用户昵称。
  ///
  final String? nickName;

  ///
  ///
  ///
  /// 用户头像。
  ///
  final String? avatarUrl;

  ///
  ///
  ///
  /// 用户邮箱。
  ///
  final String? mail;

  ///
  ///
  ///
  /// 用户手机号。
  ///
  final String? phone;

  ///
  ///
  ///
  /// 用户性别。
  /// - (默认) `0`：未知；
  /// - `1`: 男；
  /// - `2`: 女。
  ///
  final int gender;

  ///
  ///
  ///
  /// 用户签名。
  ///
  final String? sign;

  ///
  ///
  ///
  /// 用户生日。
  ///
  final String? birth;

  ///
  ///
  ///
  /// 用户自定义属性字段。
  ///
  final String? ext;

  ///
  ///
  ///
  /// 获取缓存中的用户属性到期时的时间段(秒)。如果两个调用者之间的间隔小于或等于参数中设置的值，则直接从本地缓存获取用户属性;
  /// 否则，从服务器获取。例如，如果将该参数设置为120(2分钟)，则在2分钟内再次调用该方法，SDK将返回上次获取的属性。
  ///
  final int expireTime = DateTime.now().millisecondsSinceEpoch;
}
