import 'package:im_flutter_sdk/src/internal/inner_headers.dart';

///
///
///
/// 从服务端查询历史消息的参数配置类。
///
class FetchMessageOptions {
  ///
  ///
  ///
  /// 从服务端查询历史消息的参数配置类。
  ///
  /// Param [direction] 消息搜索方向。默认为 [EMSearchDirection.Up] , 详见 [EMSearchDirection]。
  ///
  /// Param [from] 群组会话中的消息发送方的用户 ID。
  ///
  /// Param [msgTypes] 要查询的消息类型数组。默认值为 `null`，表示返回所有类型的消息。
  ///
  /// Param [startTs] 消息查询的起始时间，Unix 时间戳，单位为毫秒。默认为 `-1`，表示消息查询时会忽略该参数。
  /// 若 [startTs] 设置为特定时间点，而 [endTs] 采用默认值 `-1`，则查询起始时间至当前时间的消息。
  /// 若 [startTs] 采用默认值 `-1`，而 [endTs] 设置了特定时间，SDK 返回从会话中最早的消息到结束时间点的消息。
  ///
  /// Param [endTs] 消息查询的结束时间，Unix 时间戳，单位为毫秒。默认为 -1，表示消息查询时会忽略该参数。
  /// 若 [startTs] 设置为特定时间点，而 [endTs] 采用默认值 -1，则查询起始时间至当前时间的消息。
  /// 若 [startTs] 采用默认值 -1，而 [endTs] 设置了特定时间，SDK 返回从会话中最早的消息到结束时间点的消息。
  ///
  /// Param [needSave] 获取的消息是否保存到数据库：
  /// - `true`：保存到数据库；
  /// - `false`（默认）：不保存到数据库。
  ///
  const FetchMessageOptions({
    this.from,
    this.msgTypes,
    this.startTs = -1,
    this.endTs = -1,
    this.needSave = false,
    this.direction = EMSearchDirection.Up,
  });

  ///
  ///
  ///
  /// 群组会话中的消息发送方的用户 ID。
  ///
  final String? from;

  ///
  ///
  ///
  /// 要查询的消息类型数组。默认值为 `null`，表示返回所有类型的消息。
  ///
  final List<MessageType>? msgTypes;

  ///
  ///
  ///
  /// 消息查询的起始时间，Unix 时间戳，单位为毫秒。默认为 -1，表示消息查询时会忽略该参数。
  /// 若 [startTs] 设置为特定时间点，而 [endTs] 采用默认值 -1，则查询起始时间至当前时间的消息。
  /// 若 [startTs] 采用默认值 -1，而 [endTs] 设置了特定时间，SDK 返回从会话中最早的消息到结束时间点的消息。
  ///
  final int startTs;

  ///
  ///
  ///
  /// 消息查询的结束时间，Unix 时间戳，单位为毫秒。默认为 `-1`，表示消息查询时会忽略该参数。
  /// 若 [startTs] 设置为特定时间点，而 [endTs] 采用默认值 `-1`，则查询起始时间至当前时间的消息。
  /// 若 [startTs] 采用默认值 `-1`，而 [endTs] 设置了特定时间，SDK 返回从会话中最早的消息到结束时间点的消息。
  ///
  final int endTs;

  ///
  ///
  ///
  /// 消息搜索方向，默认为[EMSearchDirection.Up]。详见 [EMSearchDirection]。
  ///
  final EMSearchDirection direction;

  ///
  ///
  ///
  /// 获取的消息是否保存到数据库：
  /// - `true`：保存到数据库；
  /// - （默认）`false`：不保存到数据库。
  ///
  final bool needSave;

  Map toJson() {
    Map data = {};
    data.putIfNotNull(
        'direction', direction == EMSearchDirection.Up ? "up" : "down");
    data.putIfNotNull('startTs', startTs);
    data.putIfNotNull('endTs', endTs);
    data.putIfNotNull('from', from);
    data.putIfNotNull('needSave', needSave);
    data.putIfNotNull('msgTypes',
        msgTypes?.toSet().map<String>((e) => messageTypeToTypeStr(e)).toList());

    return data;
  }
}
